body {
    padding-top: 70px;
}

div.incidents {
    margin-top: 5em;
}

small.timeinfo {
    opacity: 0.7;
}

div.servicegroup a.servicegroup-name {
    color: black;
    text-decoration: none;
    cursor: pointer;
}

div.servicegroup a.servicegroup-name:before {
    font-family: 'Glyphicons Halflings';
    font-size: 80%;
    content: "\e114";
    padding-right: 3px;
}
div.servicegroup a.servicegroup-name.collapsed:before {
    content: "\e080 ";
}

.dot {
    display: inline-block;
    border-radius: 50%;
    width: 50%;
    background-color: #EEE;
    height: 15px;
    width: 15px;
    margin: 0 2px;
    vertical-align: baseline;
}
.dot.dot-success {
    background-color: #449D44;
}
.dot.dot-info {
    background-color: #5BC0DE;
}
.dot.dot-warning {
    background-color: #F0AD4E;
}
.dot.dot-danger {
    background-color: #D9534F;
}

.form-signin {
    max-width: 330px;
    margin: 0 auto;
}
